pub struct Snapshot {
pub id: String,
pub graph: SourceCodeGraph,
pub vibes: Vec<Vibe>,
pub cell_states: Vec<CellState>,
pub constitution: Constitution,
pub created_at: SystemTime,
}Expand description
Represents a snapshot of the entire system ready to be fossilized in Git.
Fields
id: StringIdentifier suitable for referencing the snapshot in storage.
graph: SourceCodeGraphCaptured graph at the time of snapshot.
vibes: Vec<Vibe>All vibes considered part of the snapshot.
cell_states: Vec<CellState>Cell states for the automaton corresponding to the snapshot.
constitution: ConstitutionConstitution in effect when the snapshot was created.
created_at: SystemTimeTimestamp for when the snapshot was recorded.